@@ -13,7 +13,9 @@ class is_eitc_qualifying_child(Variable):
         disabled = person("is_permanently_and_totally_disabled", period)
         age = person("age", period)
         student = person("is_full_time_student", period)
-        max_ages = parameters(period).irs.credits.eitc.qualifying_child.max_age
+        max_ages = parameters(
+            period
+        ).gov.irs.credits.eitc.qualifying_child.max_age
         max_age = where(student, max_ages.student, max_ages.non_student)
         age_qualifies = age <= max_age
         return dependent & (age_qualifies | disabled)
